@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, Type
+from typing import Any, Dict, Mapping, Type
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -42,7 +42,7 @@ __all__ = ("ApplicationCostProfilerClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -58,7 +58,7 @@ class Exceptions:
 
 class ApplicationCostProfilerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_applicationcostprofiler/client.html)
     """
 
@@ -74,7 +74,7 @@ class ApplicationCostProfilerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_applicationcostprofiler/client.html#can_paginate)
         """
 
@@ -82,21 +82,21 @@ class ApplicationCostProfilerClient(BaseClient):
         """
         Deletes the specified report definition in AWS Application Cost Profiler.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.delete_report_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.delete_report_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_applicationcostprofiler/client.html#delete_report_definition)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_applicationcostprofiler/client.html#generate_presigned_url)
         """
 
@@ -105,7 +105,7 @@ class ApplicationCostProfilerClient(BaseClient):
         Retrieves the definition of a report already configured in AWS Application Cost
         Profiler.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.get_report_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.get_report_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_applicationcostprofiler/client.html#get_report_definition)
         """
 
@@ -115,17 +115,17 @@ class ApplicationCostProfilerClient(BaseClient):
         """
         Ingests application usage data from Amazon Simple Storage Service (Amazon S3).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.import_application_usage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.import_application_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_applicationcostprofiler/client.html#import_application_usage)
         """
 
     def list_report_definitions(
-        self, *, nextToken: str = None, maxResults: int = None
+        self, *, nextToken: str = ..., maxResults: int = ...
     ) -> ListReportDefinitionsResultTypeDef:
         """
         Retrieves a list of all reports and their configurations for your AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.list_report_definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.list_report_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_applicationcostprofiler/client.html#list_report_definitions)
         """
 
@@ -141,7 +141,7 @@ class ApplicationCostProfilerClient(BaseClient):
         """
         Creates the report definition for a report in Application Cost Profiler.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.put_report_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.put_report_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_applicationcostprofiler/client.html#put_report_definition)
         """
 
@@ -157,7 +157,7 @@ class ApplicationCostProfilerClient(BaseClient):
         """
         Updates existing report in AWS Application Cost Profiler.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.update_report_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Client.update_report_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_applicationcostprofiler/client.html#update_report_definition)
         """
 
@@ -165,6 +165,6 @@ class ApplicationCostProfilerClient(BaseClient):
         self, operation_name: Literal["list_report_definitions"]
     ) -> ListReportDefinitionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Paginator.ListReportDefinitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/applicationcostprofiler.html#ApplicationCostProfiler.Paginator.ListReportDefinitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_applicationcostprofiler/paginators.html#listreportdefinitionspaginator)
         """
